@@ -10,7 +10,11 @@ config() {
   fi
   # Otherwise, we leave the .new copy for the admin to consider...
 }
-config usr/share/ghostscript/8.62/lib/cidfmap.new
+config usr/share/ghostscript/8.63/lib/cidfmap.new
+( cd usr/lib ; rm -rf libgs.so )
+( cd usr/lib ; ln -sf libgs.so.8.63 libgs.so )
+( cd usr/lib ; rm -rf libgs.so.8 )
+( cd usr/lib ; ln -sf libgs.so.8.63 libgs.so.8 )
 ( cd usr/man/man1 ; rm -rf eps2eps.1.gz )
 ( cd usr/man/man1 ; ln -sf ps2ps.1.gz eps2eps.1.gz )
 ( cd usr/man/man1 ; rm -rf ps2pdf12.1.gz )
@@ -23,5 +27,5 @@ config usr/share/ghostscript/8.62/lib/cidfmap.new
 ( cd usr/man/de/man1 ; ln -sf ps2pdf.1.gz ps2pdf12.1.gz )
 ( cd usr/man/de/man1 ; rm -rf ps2pdf13.1.gz )
 ( cd usr/man/de/man1 ; ln -sf ps2pdf.1.gz ps2pdf13.1.gz )
-( cd usr/doc/ghostscript-8.62 ; rm -rf doc )
-( cd usr/doc/ghostscript-8.62 ; ln -sf /usr/share/ghostscript/8.62/doc doc )
+( cd usr/doc/ghostscript-8.63 ; rm -rf doc )
+( cd usr/doc/ghostscript-8.63 ; ln -sf /usr/share/ghostscript/8.63/doc doc )
